/*!
 * Copyright 2011 Michael Phan-Ba
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Module dependencies.
 */

var fs = require('fs');

/**
 * Initialize a new `JsonEncoder` with the given `options`.
 *
 * @param {Object} (optional) options
 * @api public
 */

var JsonEncoder = exports.JsonEncoder = function(options) {
};

/**
 * Prototype.
 */

JsonEncoder.prototype = {

  /**
   * Encode a value.
   *
   * @param {String} value
   * @return {String}
   * @api public
   */

  encode: function(value) {
    if (typeof value === 'undefined') return 'null';

    if (typeof value === 'string') {
      if (value.indexOf('"') !== -1) {
        return encodeURIComponent(value);
      }
      return JSON.stringify(value);
    }

    return encodeURIComponent(JSON.stringify(value));
  },

  /**
   * Decode a value.
   *
   * @param {String} value
   * @return {Cookie} the parsed cookie or `null` on failure
   * @api public
   */

  decode: function(value) {
    if (value[0] === '"') return value.slice(1, -1);

    var noJson = value.indexOf('%22') === 0;

    value = value.replace(/\+/g, ' ');

    try {
      value = decodeURIComponent(value);
    } catch (err) {
      if (!(err instanceof URIError)) {
        throw err;
      }
    }

    if (noJson) return value;

    try {
      value = JSON.parse(value);
    } catch (err) {
      if (!(err instanceof SyntaxError)) {
        throw err;
      }
    }

    return value;
  }
};

/**
 * Default instance.
 */

exports.encoder = new JsonEncoder();
