/*!
 * Copyright 2011 Michael Phan-Ba
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Module dependencies.
 */

var crypto = require('crypto')
  , util = require('../util');

/**
 * Lambdas.
 */

var lowercase = function(x) { return x.toLowerCase(); };

/**
 * Initialize a new `HeaderFingerprinter` with the given `options`.
 *
 * Options:
 *   - `headers`: request headers to fingerprint. Defaults to
 *     `['user-agent']` but could take on something like
 *     `['user-agent', 'accept', 'accept-language']`
 *
 * @param {Object} (optional) options
 * @api public
 */

var HeaderFingerprinter = exports.HeaderFingerprinter = function(options) {
  if (options && options.headers) {
    this.headers = options.headers.sort().map(lowercase);
  }
};

/**
 * Prototype.
 */

HeaderFingerprinter.prototype = {

  /**
   * Headers to fingerprint.
   */

  headers: ['user-agent'],

  /**
   * Fingerprints a request.
   *
   * @param {Request} req
   * @return {String}
   * @api public
   */

  fingerprint: function(req) {
    var print = [];

    for (var i = 0, name; name = this.headers[i]; i++) {
      var header = req.headers[name];
      if (header) print.push(header);
    }

    return print.join('');
  }
};

/**
 * Default instance.
 */

exports.fingerprinter = new HeaderFingerprinter;
