/*!
 * Copyright 2011 Michael Phan-Ba
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Module dependencies.
 */

var crypto = require('crypto')
  , util = require('../util');

/**
 * Initialize a new `HmacSigner` with the given `options`.
 *
 * Options:
 *   - `algorithm` the HMAC hash algorithm
 *
 * @param {Object} (optional) options
 * @api public
 */

var HmacSigner = exports.HmacSigner = function(options) {
  this.algorithm = (options && options.algorithm) || 'sha1';
};

/**
 * Prototype.
 */

HmacSigner.prototype = {

  /**
   * Digest a value.
   *
   * @param {String} value
   * @param {String} salt
   * @return {String}
   * @api public
   */

  sign: function(value, salt) {
    var hmac = crypto.createHmac(this.algorithm, salt)
      , hash = hmac.update(value).digest('base64');
    return util.b64unpad(hash);
  }
};

/**
 * Default instance.
 */

exports.signer = new HmacSigner;
