/*!
 * Copyright 2011 Michael Phan-Ba
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Module dependencies.
 */

var vows = require('vows')
  , assert = require('assert')
  , JsonEncoder = require('../../lib/encoders/json').JsonEncoder;

/**
 * Vows tests.
 */

vows.describe('JsonEncoder').addBatch({
  'when JSON encoding': {
    topic: function() {
      return new JsonEncoder();
    },
    'should encode a string value': function(topic) {
      var input = 'Hello World!'
        , encoded = topic.encode(input)
        , output = topic.decode(encoded);
      assert.equal(encoded, '"Hello World!"');
      assert.equal(output, input);
    },
    'should encode a string value with a quote': function(topic) {
      var input = '"Hello World!"'
        , encoded = topic.encode(input)
        , output = topic.decode(encoded);
      assert.equal(encoded, '%22Hello%20World!%22');
      assert.equal(output, input);
    },
    'should encode an object': function(topic) {
      var input = { message: 'Hello World!' }
        , encoded = topic.encode(input)
        , output = topic.decode(encoded);
      assert.equal(encoded, '%7B%22message%22%3A%22Hello%20World!%22%7D');
      assert.deepEqual(output, input);
    },
    'should encode an array': function(topic) {
      var input = ['Hello World!']
        , encoded = topic.encode(input)
        , output = topic.decode(encoded);
      assert.equal(encoded, '%5B%22Hello%20World!%22%5D');
      assert.deepEqual(output, input);
    },
    'should encode a number': function(topic) {
      var input = 42
        , encoded = topic.encode(input)
        , output = topic.decode(encoded);
      assert.equal(encoded, '42');
      assert.equal(output, input);
    },
    'should encode true': function(topic) {
      var encoded = topic.encode(true)
        , output = topic.decode(encoded);
      assert.isTrue(output);
    },
    'should encode false': function(topic) {
      var encoded = topic.encode(false)
        , output = topic.decode(encoded);
      assert.isFalse(output);
    },
    'should encode null': function(topic) {
      var encoded = topic.encode(null)
        , output = topic.decode(encoded);
      assert.isNull(output);
    },
    'should encode undefined': function(topic) {
      var encoded = topic.encode(undefined)
        , output = topic.decode(encoded);
      assert.isNull(output);
    }
  }
}).export(module);
