/*!
 * Copyright 2011 Michael Phan-Ba
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Module dependencies.
 */

var vows = require('vows')
  , assert = require('assert')
  , Cookie = require('../../lib/cookie').Cookie
  , CookieJar = require('../../lib/cookiejar').CookieJar
  , HeaderFingerprinter = require('../../lib/fingerprinters/header').HeaderFingerprinter;

/**
 * Vows tests.
 */

vows.describe('HeaderFingerprinter').addBatch({
  'when using default options': {
    topic: function() {
      return new HeaderFingerprinter();
    },
    'should be ok': function(topic) {
      var userAgent = 'User-Agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_1) AppleWebKit/535.2+ (KHTML, like Gecko) Version/5.1 Safari/534.48.3'
        , print = topic.fingerprint({ headers: { 'user-agent': userAgent }});
      assert.equal(print, userAgent);
    }
  },
  'when using headers [User-Agent, Accept] options': {
    topic: function() {
      return new HeaderFingerprinter({ headers: ['User-Agent', 'Accept']});
    },
    'should sort and lowercase the option': function(topic) {
      assert.equal(topic.headers[0], 'accept');
      assert.equal(topic.headers[1], 'user-agent');
    },
    'should concatenate header values': function(topic) {
      var userAgent = 'User-Agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_1) AppleWebKit/535.2+ (KHTML, like Gecko) Version/5.1 Safari/534.48.3'
        , accept = 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8'
        , print = topic.fingerprint({ headers: { 'user-agent': userAgent, accept: accept }});
      assert.equal(print, accept + userAgent);
    }
  }
}).export(module);
