/*!
 * Copyright 2011 Michael Phan-Ba
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Module dependencies.
 */

var vows = require('vows')
  , assert = require('assert')
  , index = require('../lib/index')
  , Cookie = require('../lib/cookie').Cookie
  , CookieJar = require('../lib/cookiejar').CookieJar
  , cookieManager = require('../lib/middleware')
  , defaultEncoder = require('../lib/encoders/json').encoder
  , defaultSigner = require('../lib/signers/hmac').signer
  , defaultFingerprinter = require('../lib/fingerprinters/header').fingerprinter
  , JsonEncoder = require('../lib/encoders/json').JsonEncoder
  , AesEncoder = require('../lib/encoders/aes').AesEncoder
  , HmacSigner = require('../lib/signers/hmac').HmacSigner
  , HeaderFingerprinter = require('../lib/fingerprinters/header').HeaderFingerprinter;

/**
 * Vows tests.
 */

vows.describe('index').addBatch({
  'when exporting modules': {
    topic: function() {
      return index;
    },
    'should export Cookie': function(topic) {
      assert.isFunction(topic.Cookie);
      assert.strictEqual(topic.Cookie, Cookie);
    },
    'should export CookieJar': function(topic) {
      assert.isFunction(topic.CookieJar);
      assert.strictEqual(topic.CookieJar, CookieJar);
    },
    'should export cookieManager': function(topic) {
      assert.isFunction(topic.cookieManager);
      assert.strictEqual(topic.cookieManager, cookieManager);
    },
    'should export defaultEncoder': function(topic) {
      assert.isObject(topic.defaultEncoder);
      assert.strictEqual(topic.defaultEncoder, defaultEncoder);
    },
    'should export defaultSigner': function(topic) {
      assert.isObject(topic.defaultSigner);
      assert.strictEqual(topic.defaultSigner, defaultSigner);
    },
    'should export defaultFingerprinter': function(topic) {
      assert.isObject(topic.defaultFingerprinter);
      assert.strictEqual(topic.defaultFingerprinter, defaultFingerprinter);
    },
    'should export JsonEncoder': function(topic) {
      assert.isFunction(topic.JsonEncoder);
      assert.strictEqual(topic.JsonEncoder, JsonEncoder);
    },
    'should export AesEncoder': function(topic) {
      assert.isFunction(topic.AesEncoder);
      assert.strictEqual(topic.AesEncoder, AesEncoder);
    },
    'should export HmacSigner': function(topic) {
      assert.isFunction(topic.HmacSigner);
      assert.strictEqual(topic.HmacSigner, HmacSigner);
    },
    'should export HeaderFingerprinter': function(topic) {
      assert.isFunction(topic.HeaderFingerprinter);
      assert.strictEqual(topic.HeaderFingerprinter, HeaderFingerprinter);
    }
  }
}).export(module);
