/*!
 * Copyright 2011 Michael Phan-Ba
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Module dependencies.
 */

var vows = require('vows')
  , assert = require('assert')
  , util = require('../lib/util');

/**
 * Vows tests.
 */

vows.describe('util').addBatch({
  'when using b64unpad()': {
    topic: function() {
      return util.b64unpad;
    },
    'should strip no padding': function(topic) {
      assert.equal(topic(''), '');
      assert.equal(topic('AAAA'), 'AAAA');
    },
    'should strip 1 padding': function(topic) {
      assert.equal(topic('AAA'), 'AAA');
    },
    'should strip 2 padding': function(topic) {
      assert.equal(topic('AA'), 'AA');
    },
    'should strip 3 padding': function(topic) {
      assert.equal(topic('A'), 'A');
    }
  },
  'when using b64repad()': {
    topic: function() {
      return util.b64repad;
    },
    'should restore no padding': function(topic) {
      assert.equal(topic(''), '');
      assert.equal(topic('AAAA'), 'AAAA');
    },
    'should restore 1 padding': function(topic) {
      assert.equal(topic('AAA'), 'AAA=');
    },
    'should restore 2 padding': function(topic) {
      assert.equal(topic('AA'), 'AA==');
    },
    'should restore 3 padding': function(topic) {
      assert.equal(topic('A'), 'A===');
    }
  }
}).export(module);
